@@ -330,10 +330,10 @@ function ShowRecentFileList( pList )
 	{
 		let OneFile=pList[n];
 		
-		let sPath=OneFile['path'];
-		let sImg=OneFile["image"] || sImages[sPath];
+		let sPath=DOMPurify.sanitize(OneFile['path']);
+		let sImg=DOMPurify.sanitize(OneFile["image"]) || sImages[sPath];
 		let sTime=OneFile['time'];
-		let sName=OneFile['project_name'];
+		let sName=DOMPurify.sanitize(OneFile['project_name']);
 		sImages[sPath] = sImg;
 		
 		//let index=sPath.lastIndexOf('\\')>0?sPath.lastIndexOf('\\'):sPath.lastIndexOf('\/');
@@ -482,14 +482,22 @@ function OnDeleteRecentFile( )
 
 function OnDeleteAllRecentFiles()
 {
-	$('#FileList').html('');
-	UpdateRecentClearBtnDisplay();
-	
-	var tSend={};
-	tSend['sequence_id']=Math.round(new Date() / 1000);
-	tSend['command']="homepage_delete_all_recentfile";
-	
-	SendWXMessage( JSON.stringify(tSend) );
+	showConfirmDialog({
+		title: GetCurrentTextByKey("t39"),
+		message: GetCurrentTextByKey("t149"),
+		okText: GetCurrentTextByKey("t21"),
+		cancelText: GetCurrentTextByKey("t22"),
+		onOk: function() {
+			$('#FileList').html('');
+			UpdateRecentClearBtnDisplay();
+			
+			var tSend={};
+			tSend['sequence_id']=Math.round(new Date() / 1000);
+			tSend['command']="homepage_delete_all_recentfile";
+			
+			SendWXMessage( JSON.stringify(tSend) );
+		}
+	});
 }
 
 function UpdateRecentClearBtnDisplay()
